package de.intevation.gnv.jfreechart;

import java.util.List;
import java.util.ArrayList;

import org.jfree.data.Range;
import org.jfree.data.general.AbstractSeriesDataset;

/**
 * @author Ingo Weinzierl <ingo.weinzierl@intevation.de>
 */
public class PolygonDataset
extends      AbstractSeriesDataset
{
    /** PolygonSeries included in this Dataset */
    private List data;


    public PolygonDataset() {
        this(null);
    }


    public PolygonDataset(PolygonSeries series) {
        data = new ArrayList();

        if (series != null) {
            data.add(series);
        }
    }


    public void addSeries(PolygonSeries series) {
        if (series == null)
            throw new IllegalArgumentException("Null 'series' argument.");

        data.add(series);
    }


    public Range getDomainBounds() {
        double lower       = Double.POSITIVE_INFINITY;
        double upper       = Double.NEGATIVE_INFINITY;
        int    seriesCount = getSeriesCount();

        for (int s = 0; s < seriesCount; s++) {
            PolygonSeries series = getSeries(s);

            Range domainRange = series.getDomainBounds();
            double minX = domainRange.getLowerBound();
            if (!Double.isNaN(minX)) {
                lower = Math.min(lower, minX);
            }

            double maxX = domainRange.getUpperBound();
            if (!Double.isNaN(maxX)) {
                upper = Math.max(upper, maxX);
            }
        }

        return new Range(lower, upper);
    }


    public Range getRangeBounds() {
        double lower       = Double.POSITIVE_INFINITY;
        double upper       = Double.NEGATIVE_INFINITY;
        int    seriesCount = getSeriesCount();

        for (int i = 0; i < seriesCount; i++) {
            PolygonSeries series = getSeries(i);

            Range range = series.getRangeBounds();
            double minX = range.getLowerBound();
            if (!Double.isNaN(minX)) {
                lower = Math.min(lower, minX);
            }

            double maxX = range.getUpperBound();
            if (!Double.isNaN(maxX)) {
                upper = Math.max(upper, maxX);
            }
        }

        return new Range(lower, upper);
    }


    public int getSeriesCount() {
        return data.size();
    }


    public Comparable getSeriesKey(int series) {
        return ((PolygonSeries)data.get(series)).getKey();
    }


    public PolygonSeries getSeries(int idx) {
        return (PolygonSeries)data.get(idx);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
